@@ -20,8 +20,9 @@
 plot.soil_cover_tibble <- function(x,...) {
   ggplot2::ggplot(data = x, ggplot2::aes(x = date)) + 
     ggplot2::scale_x_date(date_breaks = "1 year",date_labels = "%Y") +
-    ggplot2::geom_area(fill = "brown", ggplot2::aes(y = soil_cover)) +
-    ggplot2::geom_area(fill = "chartreuse4", ggplot2::aes(y = plant_cover)) +
+    ggplot2::geom_area(fill = "chartreuse4", ggplot2::aes(y = crop_cover)) +
+    ggplot2::geom_area(fill = "green3", ggplot2::aes(y = CC_cover)) +
+    ggplot2::geom_area(fill = "brown", ggplot2::aes(y = residue_cover)) +
     ggplot2::geom_point(data = x %>% dplyr::filter(soil_cover_days != 0), fill = "black", ggplot2::aes(y = soil_cover_days*30), size = .2) +
     ggthemes::theme_few() +
     ggplot2::labs(y  = "soil cover [%]", x = "date") +
