@@ -5,7 +5,7 @@ test_that("input error", {
 })
 
 test_that("test EXAMPLE data", {
-  expect_equal(plant_diversity(EXAMPLE_data,2015,2018),dplyr::tibble(PDI_Tiemann = 42.25,
+  expect_equal(plant_diversity(EXAMPLE_data,2015,2018),dplyr::tibble(CDI_Tiemann = 42.25,
                                                                      Species_rotation = 13,
                                                                      Shannon = 2.56494936),
                ignore_attr = TRUE)
